//VERTEX SHADER
//This shader acts at a per-vertex level
//DICE supports OpenGL 2.1 and therefore GLSL 1.3 or lower.  
#version 130

//Set floats to have best precision
#ifdef GL_FRAGMENT_PRECISION_HIGH
        precision highp float;
#else
        precision mediump float;
#endif

uniform mat4 projectionMatrix; //Projection matrix for the camera (perspective or orthographic)
uniform mat4 viewMatrix; //Transformation matrix for camera position
uniform mat4 modelMatrix; //Transformation matrix for the teapot model

//"in" variables are provided by use of glBindBuffer and glVertexAttribPointer.
in vec3 in_position; //Input variable for the vertex position (provided by binding appropriate VBO, see demo1.cc)

//"out" variables are used to pass info from vertex shader to fragment shader 
out vec3 pass_color;


void main(void) {
  //Set position with the MVP matrix
  gl_Position = projectionMatrix * viewMatrix * modelMatrix * vec4(in_position, 1.0); 
 
  //gl_Color corresponds to values set with glColor*f();  
  //This should instead be calculated with lighting equations and material properties in the fragment shader
  pass_color = vec3(gl_Color);
//  pass_color = vec3(gl_Position[0]+0.5,gl_Position[0]+0.5, gl_Position[0]+0.5);
}
